# Change Log

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

<a name="2.0.0"></a>
## 2.0.0 (2020-07-07)

### Deprecations

* Stop supporting python 2.7
* Remove obsolete upload methods

<a name="1.0.0"></a>
## 1.0.0 (2018-11-27)

### Features

* First release
